@@ -1,5 +1,5 @@
 /***************************************************************************
-    copyright            : (C) 2005-2006 by Robby Stephenson
+    copyright            : (C) 2005-2008 by Robby Stephenson
     email                : robby@periapsis.org
  ***************************************************************************/
 
@@ -24,12 +24,13 @@ namespace Tellico {
  */
 class FileCatalog : public Collection {
 Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
   FileCatalog(bool addFields, const TQString& title = TQString());
 
   virtual Type type() const { return File; }
+  virtual int sameEntry(Data::EntryPtr entry1, Data::EntryPtr entry2) const;
 
   static FieldVec defaultFields();
 };
