@@ -31,18 +31,18 @@
 #include "../tellico_debug.h"
 
 #include <klineedit.h>
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include <kstandarddirs.h>
 #include <knuminput.h>
 #include <kpushbutton.h>
 #include <kiconloader.h>
 #include <ksortablevaluelist.h>
-#include <kaccelmanager.h>
-#include <khtmlview.h>
-#include <kfiledialog.h>
+#include <tdeaccelmanager.h>
+#include <tdehtmlview.h>
+#include <tdefiledialog.h>
 #include <kinputdialog.h>
-#include <kfontcombo.h>
+#include <tdefontcombo.h>
 #include <kcolorcombo.h>
 
 #include <tqsize.h>
@@ -71,9 +71,9 @@ namespace {
 using Tellico::SourceListViewItem;
 using Tellico::ConfigDialog;
 
-SourceListViewItem::SourceListViewItem(KListView* parent_, const GeneralFetcherInfo& info_,
+SourceListViewItem::SourceListViewItem(TDEListView* parent_, const GeneralFetcherInfo& info_,
                                        const TQString& groupName_)
-    : KListViewItem(parent_, info_.name), m_info(info_),
+    : TDEListViewItem(parent_, info_.name), m_info(info_),
       m_configGroup(groupName_), m_newSource(groupName_.isNull()), m_fetcher(0) {
   TQPixmap pix = Fetch::Manager::fetcherIcon(info_.type);
   if(!pix.isNull()) {
@@ -81,9 +81,9 @@ SourceListViewItem::SourceListViewItem(KListView* parent_, const GeneralFetcherI
   }
 }
 
-SourceListViewItem::SourceListViewItem(KListView* parent_, TQListViewItem* after_,
+SourceListViewItem::SourceListViewItem(TDEListView* parent_, TQListViewItem* after_,
                                        const GeneralFetcherInfo& info_, const TQString& groupName_)
-    : KListViewItem(parent_, after_, info_.name), m_info(info_),
+    : TDEListViewItem(parent_, after_, info_.name), m_info(info_),
       m_configGroup(groupName_), m_newSource(groupName_.isNull()), m_fetcher(0) {
   TQPixmap pix = Fetch::Manager::fetcherIcon(info_.type);
   if(!pix.isNull()) {
@@ -194,7 +194,7 @@ void ConfigDialog::slotDefault() {
 }
 
 void ConfigDialog::setupGeneralPage() {
-  TQPixmap pix = DesktopIcon(TQString::fromLatin1("tellico"), KIcon::SizeMedium);
+  TQPixmap pix = DesktopIcon(TQString::fromLatin1("tellico"), TDEIcon::SizeMedium);
   TQFrame* frame = addPage(i18n("General"), i18n("General Options"), pix);
   TQVBoxLayout* l = new TQVBoxLayout(frame, KDialog::marginHint(), KDialog::spacingHint());
 
@@ -281,16 +281,16 @@ void ConfigDialog::setupGeneralPage() {
 void ConfigDialog::setupPrintingPage() {
   // SuSE changed the icon name on me
   TQPixmap pix;
-  KIconLoader* loader = KGlobal::iconLoader();
+  TDEIconLoader* loader = TDEGlobal::iconLoader();
   if(loader) {
-    pix = loader->loadIcon(TQString::fromLatin1("printer1"), KIcon::Desktop, KIcon::SizeMedium,
-                           KIcon::DefaultState, 0, true /*canReturnNull */);
+    pix = loader->loadIcon(TQString::fromLatin1("printer"), TDEIcon::Desktop, TDEIcon::SizeMedium,
+                           TDEIcon::DefaultState, 0, true /*canReturnNull */);
     if(pix.isNull()) {
-      pix = loader->loadIcon(TQString::fromLatin1("printer2"), KIcon::Desktop, KIcon::SizeMedium,
-                             KIcon::DefaultState, 0, true /*canReturnNull */);
+      pix = loader->loadIcon(TQString::fromLatin1("printer2"), TDEIcon::Desktop, TDEIcon::SizeMedium,
+                             TDEIcon::DefaultState, 0, true /*canReturnNull */);
     }
     if(pix.isNull()) {
-      pix = loader->loadIcon(TQString::fromLatin1("print_printer"), KIcon::Desktop, KIcon::SizeMedium);
+      pix = loader->loadIcon(TQString::fromLatin1("print_printer"), TDEIcon::Desktop, TDEIcon::SizeMedium);
     }
   }
   TQFrame* frame = addPage(i18n("Printing"), i18n("Printing Options"), pix);
@@ -351,7 +351,7 @@ void ConfigDialog::setupPrintingPage() {
 }
 
 void ConfigDialog::setupTemplatePage() {
-  TQPixmap pix = DesktopIcon(TQString::fromLatin1("looknfeel"), KIcon::SizeMedium);
+  TQPixmap pix = DesktopIcon(TQString::fromLatin1("preferences-desktop"), TDEIcon::SizeMedium);
   TQFrame* frame = addPage(i18n("Templates"), i18n("Template Options"), pix);
   TQVBoxLayout* l = new TQVBoxLayout(frame, KDialog::marginHint(), KDialog::spacingHint());
 
@@ -404,7 +404,7 @@ void ConfigDialog::setupTemplatePage() {
 
   lab = new TQLabel(i18n("Font:"), fontGroup);
   fontLayout->addWidget(lab, ++row, 0);
-  m_fontCombo = new KFontCombo(fontGroup);
+  m_fontCombo = new TDEFontCombo(fontGroup);
   fontLayout->addWidget(m_fontCombo, row, 1);
   connect(m_fontCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotModified()));
   lab->setBuddy(m_fontCombo);
@@ -493,16 +493,16 @@ void ConfigDialog::setupTemplatePage() {
   // stretch to fill lower area
   l->addStretch(1);
 
-  KAcceleratorManager::manage(frame);
+  TDEAcceleratorManager::manage(frame);
 }
 
 void ConfigDialog::setupFetchPage() {
-  TQPixmap pix = DesktopIcon(TQString::fromLatin1("network"), KIcon::SizeMedium);
+  TQPixmap pix = DesktopIcon(TQString::fromLatin1("network"), TDEIcon::SizeMedium);
   TQFrame* frame = addPage(i18n("Data Sources"), i18n("Data Source Options"), pix);
   TQHBoxLayout* l = new TQHBoxLayout(frame, KDialog::marginHint(), KDialog::spacingHint());
 
   TQVBoxLayout* leftLayout = new TQVBoxLayout(l);
-  m_sourceListView = new KListView(frame);
+  m_sourceListView = new TDEListView(frame);
   m_sourceListView->addColumn(i18n("Source"));
   m_sourceListView->setResizeMode(TQListView::LastColumn);
   m_sourceListView->setSorting(-1); // no sorting
@@ -515,18 +515,18 @@ void ConfigDialog::setupFetchPage() {
   leftLayout->addWidget(hb);
   hb->setSpacing(KDialog::spacingHint());
   m_moveUpSourceBtn = new KPushButton(i18n("Move &Up"), hb);
-  m_moveUpSourceBtn->setIconSet(SmallIconSet(TQString::fromLatin1("up")));
+  m_moveUpSourceBtn->setIconSet(SmallIconSet(TQString::fromLatin1("go-up")));
   TQWhatsThis::add(m_moveUpSourceBtn, i18n("The order of the data sources sets the order "
                                           "that Tellico uses when entries are automatically updated."));
   m_moveDownSourceBtn = new KPushButton(i18n("Move &Down"), hb);
-  m_moveDownSourceBtn->setIconSet(SmallIconSet(TQString::fromLatin1("down")));
+  m_moveDownSourceBtn->setIconSet(SmallIconSet(TQString::fromLatin1("go-down")));
   TQWhatsThis::add(m_moveDownSourceBtn, i18n("The order of the data sources sets the order "
                                             "that Tellico uses when entries are automatically updated."));
 
   // these icons are rather arbitrary, but seem to vaguely fit
   TQVBoxLayout* vlay = new TQVBoxLayout(l);
   KPushButton* newSourceBtn = new KPushButton(i18n("&New..."), frame);
-  newSourceBtn->setIconSet(SmallIconSet(TQString::fromLatin1("filenew")));
+  newSourceBtn->setIconSet(SmallIconSet(TQString::fromLatin1("document-new")));
   TQWhatsThis::add(newSourceBtn, i18n("Click to add a new data source."));
   m_modifySourceBtn = new KPushButton(i18n("&Modify..."), frame);
   m_modifySourceBtn->setIconSet(SmallIconSet(TQString::fromLatin1("network")));
@@ -558,7 +558,7 @@ void ConfigDialog::setupFetchPage() {
   connect(m_removeSourceBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotRemoveSourceClicked()));
   connect(m_newStuffBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotNewStuffClicked()));
 
-  KAcceleratorManager::manage(frame);
+  TDEAcceleratorManager::manage(frame);
 }
 
 void ConfigDialog::readConfiguration() {
@@ -696,7 +696,7 @@ void ConfigDialog::saveConfiguration() {
   }
   m_removedConfigWidgets.clear();
 
-  KConfig* masterConfig = KGlobal::config();
+  TDEConfig* masterConfig = TDEGlobal::config();
 
   bool reloadFetchers = false;
   int count = 0; // start group numbering at 0
@@ -710,7 +710,7 @@ void ConfigDialog::saveConfiguration() {
     TQString group = TQString::fromLatin1("Data Source %1").arg(count);
     // in case we later change the order, clear the group now
     masterConfig->deleteGroup(group);
-    KConfigGroup configGroup(masterConfig, group);
+    TDEConfigGroup configGroup(masterConfig, group);
     configGroup.writeEntry("Name", item->text(0));
     configGroup.writeEntry("Type", item->fetchType());
     configGroup.writeEntry("UpdateOverwrite", item->updateOverwrite());
@@ -721,7 +721,7 @@ void ConfigDialog::saveConfiguration() {
     reloadFetchers = true;
   }
   // now update total number of sources
-  KConfigGroup sourceGroup(masterConfig, "Data Sources");
+  TDEConfigGroup sourceGroup(masterConfig, "Data Sources");
   sourceGroup.writeEntry("Sources Count", count);
   // and purge old config groups
   TQString group = TQString::fromLatin1("Data Source %1").arg(count);
@@ -908,7 +908,7 @@ void ConfigDialog::slotNewStuffClicked() {
       continue;
     }
 
-    KConfig spec(info.specFile, false, false);
+    TDEConfig spec(info.specFile, false, false);
     cw->readConfig(&spec);
     cw->slotSetModified();
     cw->setAccepted(true);
@@ -990,7 +990,7 @@ void ConfigDialog::slotShowTemplatePreview() {
 }
 
 void ConfigDialog::loadTemplateList() {
-  TQStringList files = KGlobal::dirs()->findAllResources("appdata", TQString::fromLatin1("entry-templates/*.xsl"),
+  TQStringList files = TDEGlobal::dirs()->findAllResources("appdata", TQString::fromLatin1("entry-templates/*.xsl"),
                                                         false, true);
   KSortableValueList<TQString, TQString> templates;
   for(TQStringList::ConstIterator it = files.begin(); it != files.end(); ++it) {
