@@ -39,10 +39,10 @@
 #include "entryupdater.h"
 #include "entrymerger.h"
 
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kaction.h>
-#include <ktoolbarbutton.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeaction.h>
+#include <tdetoolbarbutton.h>
 
 #include <tqpopupmenu.h>
 
@@ -432,8 +432,9 @@ void Controller::slotDeleteSelectedEntries() {
     TQString str = i18n("Do you really want to delete this entry?");
     TQString dontAsk = TQString::fromLatin1("DeleteEntry");
     int ret = KMessageBox::warningContinueCancel(Kernel::self()->widget(), str, i18n("Delete Entry"),
-                                                 KGuiItem(i18n("&Delete"), TQString::fromLatin1("editdelete")), dontAsk);
+                                                 KGuiItem(i18n("&Delete"), TQString::fromLatin1("edit-delete")), dontAsk);
     if(ret != KMessageBox::Continue) {
+      m_working = false;
       return;
     }
   } else {
@@ -446,8 +447,9 @@ void Controller::slotDeleteSelectedEntries() {
     TQString dontAsk = TQString::fromLatin1("DeleteMultipleBooks");
     int ret = KMessageBox::warningContinueCancelList(Kernel::self()->widget(), str, names,
                                                      i18n("Delete Multiple Entries"),
-                                                     KGuiItem(i18n("&Delete"), TQString::fromLatin1("editdelete")), dontAsk);
+                                                     KGuiItem(i18n("&Delete"), TQString::fromLatin1("edit-delete")), dontAsk);
     if(ret != KMessageBox::Continue) {
+      m_working = false;
       return;
     }
   }
@@ -566,7 +568,7 @@ void Controller::plugEntryActions(TQPopupMenu* popup_) {
   m_mainWindow->m_deleteEntry->plug(popup_);
   m_mainWindow->m_mergeEntry->plug(popup_);
   m_mainWindow->m_updateEntryMenu->plug(popup_);
-  // there's a bug in KActionMenu with KXMLGUIFactory::plugActionList
+  // there's a bug in TDEActionMenu with KXMLGUIFactory::plugActionList
   // pluging the menu action isn't enough to have the popup get populated
   plugUpdateMenu(popup_);
   popup_->insertSeparator();
@@ -591,7 +593,7 @@ void Controller::plugUpdateMenu(TQPopupMenu* popup_) {
   // I can't figure out why the actions get duplicated, but they do
   // so clear them all
   m_mainWindow->m_updateAll->unplug(updatePopup);
-  for(TQPtrListIterator<KAction> it(m_mainWindow->m_fetchActions); it.current(); ++it) {
+  for(TQPtrListIterator<TDEAction> it(m_mainWindow->m_fetchActions); it.current(); ++it) {
     it.current()->unplug(updatePopup);
   }
 
@@ -600,7 +602,7 @@ void Controller::plugUpdateMenu(TQPopupMenu* popup_) {
 
   m_mainWindow->m_updateAll->plug(updatePopup);
   updatePopup->insertSeparator();
-  for(TQPtrListIterator<KAction> it(m_mainWindow->m_fetchActions); it.current(); ++it) {
+  for(TQPtrListIterator<TDEAction> it(m_mainWindow->m_fetchActions); it.current(); ++it) {
     it.current()->plug(updatePopup);
   }
 }
@@ -609,7 +611,7 @@ void Controller::updateActions() const {
   bool emptySelection = m_selectedEntries.isEmpty();
   m_mainWindow->stateChanged(TQString::fromLatin1("empty_selection"),
                              emptySelection ? KXMLGUIClient::StateNoReverse : KXMLGUIClient::StateReverse);
-  for(TQPtrListIterator<KAction> it(m_mainWindow->m_fetchActions); it.current(); ++it) {
+  for(TQPtrListIterator<TDEAction> it(m_mainWindow->m_fetchActions); it.current(); ++it) {
     it.current()->setEnabled(!emptySelection);
   }
   //only enable citation items when it's a bibliography
