@@ -19,7 +19,7 @@
 
 class KURL;
 class KFileItem;
-namespace KIO {
+namespace TDEIO {
   class Job;
 }
 
@@ -27,7 +27,7 @@ namespace Tellico {
 
 class NetAccess : public TQObject {
 Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
   static bool download(const KURL& u, TQString& target, TQWidget* window);
