@@ -23,12 +23,12 @@
 #include "tellico_kernel.h"
 #include "core/tellico_config.h"
 
-#include <klocale.h>
-#include <kconfig.h>
-#include <kapplication.h>
-#include <kaction.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
+#include <tdeapplication.h>
+#include <tdeaction.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 #include <tqptrlist.h>
 #include <tqstringlist.h>
@@ -62,7 +62,7 @@ DetailedListView::DetailedListView(TQWidget* parent_, const char* name_/*=0*/)
   connect(header(), TQT_SIGNAL(sizeChange(int, int, int)),
           this, TQT_SLOT(slotCacheColumnWidth(int, int, int)));
 
-  m_headerMenu = new KPopupMenu(this);
+  m_headerMenu = new TDEPopupMenu(this);
   m_headerMenu->setCheckable(true);
   m_headerMenu->insertTitle(i18n("View Columns"));
   connect(m_headerMenu, TQT_SIGNAL(activated(int)),
@@ -82,7 +82,7 @@ void DetailedListView::addCollection(Data::CollPtr coll_) {
   m_imageColumns.clear();
 //  myDebug() << "DetailedListView::addCollection()" << endl;
 
-  KConfigGroup config(kapp->config(), TQString::fromLatin1("Options - %1").arg(coll_->typeName()));
+  TDEConfigGroup config(kapp->config(), TQString::fromLatin1("Options - %1").arg(coll_->typeName()));
 
   TQString configN;
   if(coll_->type() == Data::Collection::Base) {
@@ -341,7 +341,7 @@ void DetailedListView::contextMenuRequested(TQListViewItem* item_, const TQPoint
   if(!item_) {
     return;
   }
-  KPopupMenu menu(this);
+  TDEPopupMenu menu(this);
   Controller::self()->plugEntryActions(&menu);
   menu.exec(point_);
 }
@@ -747,7 +747,7 @@ void DetailedListView::slotUpdatePixmap() {
 }
 
 void DetailedListView::saveConfig(Tellico::Data::CollPtr coll_, int configIndex_) {
-  KConfigGroup config(kapp->config(), TQString::fromLatin1("Options - %1").arg(coll_->typeName()));
+  TDEConfigGroup config(kapp->config(), TQString::fromLatin1("Options - %1").arg(coll_->typeName()));
 
   // all of this is to have custom settings on a per file basis
   TQString configN;
