@@ -15,6 +15,7 @@
 #include "mainwindow.h" // needed for calling fileSave()
 #include "collectionfactory.h"
 #include "translators/tellicoimporter.h"
+#include "translators/tellicosaximporter.h"
 #include "translators/tellicozipexporter.h"
 #include "translators/tellicoxmlexporter.h"
 #include "collection.h"
@@ -30,10 +31,10 @@
 #include "progressmanager.h"
 #include "core/tellico_config.h"
 
-#include <kmessagebox.h>
-#include <klocale.h>
-#include <kglobal.h>
-#include <kapplication.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
+#include <tdeapplication.h>
 
 #include <tqregexp.h>
 #include <tqtimer.h>
@@ -109,7 +110,12 @@ bool Document::openDocument(const KURL& url_) {
   }
 
   delete m_importer;
+#ifdef SAX_SUPPORT
+  myLog() << "Document::openDocument() - using SAX loader" << endl;
+  m_importer = new Import::TellicoSaxImporter(url_, m_loadAllImages);
+#else
   m_importer = new Import::TellicoImporter(url_, m_loadAllImages);
+#endif
 
   CollPtr coll = m_importer->collection();
   // delayed image loading only works for zip files
@@ -146,6 +152,8 @@ bool Document::openDocument(const KURL& url_) {
     TQTimer::singleShot(500, this, TQT_SLOT(slotLoadAllImages()));
   } else {
     emit signalCollectionImagesLoaded(m_coll);
+    m_importer->deleteLater();
+    m_importer = 0;
   }
   return true;
 }
@@ -260,7 +268,7 @@ void Document::deleteContents() {
   if(m_coll) {
     m_coll->clear();
   }
-  m_coll = 0; // old collection gets deleted as a KSharedPtr
+  m_coll = 0; // old collection gets deleted as a TDESharedPtr
   m_cancelImageWriting = true;
 }
 
