@@ -27,12 +27,12 @@
 #include "../tellico_utils.h"
 #include "../lccnvalidator.h"
 
-#include <klocale.h>
-#include <kio/job.h>
+#include <tdelocale.h>
+#include <tdeio/job.h>
 #include <kstandarddirs.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kcombobox.h>
-#include <kaccelmanager.h>
+#include <tdeaccelmanager.h>
 #include <knuminput.h>
 
 #include <tqlabel.h>
@@ -81,7 +81,7 @@ bool SRUFetcher::canFetch(int type) const {
   return type == Data::Collection::Book || type == Data::Collection::Bibtex;
 }
 
-void SRUFetcher::readConfigHook(const KConfigGroup& config_) {
+void SRUFetcher::readConfigHook(const TDEConfigGroup& config_) {
   m_host = config_.readEntry("Host");
   int p = config_.readNumEntry("Port", SRU_DEFAULT_PORT);
   if(p > 0) {
@@ -183,11 +183,11 @@ void SRUFetcher::search(FetchKey key_, const TQString& value_) {
 #endif
 //  myDebug() << u.prettyURL() << endl;
 
-  m_job = KIO::get(u, false, false);
-  connect(m_job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-          TQT_SLOT(slotData(KIO::Job*, const TQByteArray&)));
-  connect(m_job, TQT_SIGNAL(result(KIO::Job*)),
-          TQT_SLOT(slotComplete(KIO::Job*)));
+  m_job = TDEIO::get(u, false, false);
+  connect(m_job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+          TQT_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
+  connect(m_job, TQT_SIGNAL(result(TDEIO::Job*)),
+          TQT_SLOT(slotComplete(TDEIO::Job*)));
 }
 
 void SRUFetcher::stop() {
@@ -203,12 +203,12 @@ void SRUFetcher::stop() {
   emit signalDone(this);
 }
 
-void SRUFetcher::slotData(KIO::Job*, const TQByteArray& data_) {
+void SRUFetcher::slotData(TDEIO::Job*, const TQByteArray& data_) {
   TQDataStream stream(m_data, IO_WriteOnly | IO_Append);
   stream.writeRawBytes(data_.data(), data_.size());
 }
 
-void SRUFetcher::slotComplete(KIO::Job* job_) {
+void SRUFetcher::slotComplete(TDEIO::Job* job_) {
   // since the fetch is done, don't worry about holding the job pointer
   m_job = 0;
 
@@ -492,10 +492,10 @@ SRUConfigWidget::SRUConfigWidget(TQWidget* parent_, const SRUFetcher* fetcher_ /
     m_pathEdit->setText(fetcher_->m_path);
     m_formatCombo->setCurrentData(fetcher_->m_format);
   }
-  KAcceleratorManager::manage(optionsWidget());
+  TDEAcceleratorManager::manage(optionsWidget());
 }
 
-void SRUConfigWidget::saveConfig(KConfigGroup& config_) {
+void SRUConfigWidget::saveConfig(TDEConfigGroup& config_) {
   TQString s = m_hostEdit->text().stripWhiteSpace();
   if(!s.isEmpty()) {
     config_.writeEntry("Host", s);
