@@ -37,13 +37,13 @@
 #include "../isbnvalidator.h"
 #include "../lccnvalidator.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <knuminput.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kcombobox.h>
-#include <kaccelmanager.h>
+#include <tdeaccelmanager.h>
 #include <kseparator.h>
 
 #include <tqfile.h>
@@ -88,7 +88,7 @@ bool Z3950Fetcher::canFetch(int type) const {
   return type == Data::Collection::Book || type == Data::Collection::Bibtex;
 }
 
-void Z3950Fetcher::readConfigHook(const KConfigGroup& config_) {
+void Z3950Fetcher::readConfigHook(const TDEConfigGroup& config_) {
   TQString preset = config_.readEntry("Preset");
   if(preset.isEmpty()) {
     m_host = config_.readEntry("Host");
@@ -105,7 +105,7 @@ void Z3950Fetcher::readConfigHook(const KConfigGroup& config_) {
     m_preset = preset;
     TQString serverFile = locate("appdata", TQString::fromLatin1("z3950-servers.cfg"));
     if(!serverFile.isEmpty()) {
-      KConfig cfg(serverFile, true /* read-only */, false /* read KDE */);
+      TDEConfig cfg(serverFile, true /* read-only */, false /* read KDE */);
       const TQStringList servers = cfg.groupList();
       for(TQStringList::ConstIterator server = servers.begin(); server != servers.end(); ++server) {
         cfg.setGroup(*server);
@@ -128,7 +128,7 @@ void Z3950Fetcher::readConfigHook(const KConfigGroup& config_) {
   m_fields = config_.readListEntry("Custom Fields");
 }
 
-void Z3950Fetcher::saveConfigHook(KConfigGroup& config_) {
+void Z3950Fetcher::saveConfigHook(TDEConfigGroup& config_) {
   config_.writeEntry("Syntax", m_syntax);
   config_.sync();
 }
@@ -175,13 +175,13 @@ void Z3950Fetcher::search(FetchKey key_, const TQString& value_) {
             isbnList.insert(it, isbn10);
           }
         }
-        const int count = isbnList.count();
+        const size_t count = isbnList.count();
         if(count > 1) {
           m_pqn = TQString::fromLatin1("@or ");
         }
-        for(int i = 0; i < count; ++i) {
+        for(size_t i = 0; i < count; ++i) {
           m_pqn += TQString::fromLatin1(" @attr 1=7 ") + isbnList[i];
-          if(i < count-2) {
+          if(count > 1 && i < count-2) {
             m_pqn += TQString::fromLatin1(" @or");
           }
         }
@@ -633,7 +633,7 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const Z3950Fetcher*
     m_syntax = fetcher_->m_syntax;
     m_syntaxCombo->setCurrentData(m_syntax);
   }
-  KAcceleratorManager::manage(optionsWidget());
+  TDEAcceleratorManager::manage(optionsWidget());
 
   // start with presets turned off
   m_usePreset->setChecked(fetcher_ && !fetcher_->m_preset.isEmpty());
@@ -644,7 +644,7 @@ Z3950Fetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const Z3950Fetcher*
 Z3950Fetcher::ConfigWidget::~ConfigWidget() {
 }
 
-void Z3950Fetcher::ConfigWidget::saveConfig(KConfigGroup& config_) {
+void Z3950Fetcher::ConfigWidget::saveConfig(TDEConfigGroup& config_) {
   if(m_usePreset->isChecked()) {
     TQString presetID = m_serverCombo->currentData().toString();
     config_.writeEntry("Preset", presetID);
@@ -720,11 +720,11 @@ void Z3950Fetcher::ConfigWidget::slotPresetChanged() {
 }
 
 void Z3950Fetcher::ConfigWidget::loadPresets(const TQString& current_) {
-  TQString lang = KGlobal::locale()->languageList().first();
+  TQString lang = TDEGlobal::locale()->languageList().first();
   TQString lang2A;
   {
     TQString dummy;
-    KGlobal::locale()->splitLocale(lang, lang2A, dummy, dummy);
+    TDEGlobal::locale()->splitLocale(lang, lang2A, dummy, dummy);
   }
 
   TQString serverFile = locate("appdata", TQString::fromLatin1("z3950-servers.cfg"));
@@ -735,7 +735,7 @@ void Z3950Fetcher::ConfigWidget::loadPresets(const TQString& current_) {
 
   int idx = -1;
 
-  KConfig cfg(serverFile, true /* read-only */, false /* read KDE */);
+  TDEConfig cfg(serverFile, true /* read-only */, false /* read KDE */);
   const TQStringList servers = cfg.groupList();
   // I want the list of servers sorted by name
   TQMap<TQString, TQString> serverNameMap;
