@@ -1,6 +1,9 @@
 /***************************************************************************
     copyright            : (C) 2006 by Robby Stephenson
     email                : robby@periapsis.org
+
+    Copyright (c) 2014 Timothy Pearson <kb9vqf@pearsoncomputing.net>
+
  ***************************************************************************/
 
 /***************************************************************************
@@ -12,23 +15,22 @@
  ***************************************************************************/
 
 #include "dialog.h"
-#include "providerloader.h"
 #include "../gui/listview.h"
 #include "../latin1literal.h"
 #include "../tellico_utils.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kpushbutton.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kiconloader.h>
 #include <kstatusbar.h>
-#include <kio/job.h>
-#include <kio/netaccess.h>
-#include <kaccelmanager.h>
-#include <knewstuff/entry.h>
-#include <knewstuff/provider.h>
-#include <ktempfile.h>
+#include <tdeio/job.h>
+#include <tdeio/netaccess.h>
+#include <tdeaccelmanager.h>
+#include <tdenewstuff/entry.h>
+#include <tdenewstuff/provider.h>
+#include <tdetempfile.h>
 
 #include <tqlabel.h>
 #include <tqtextedit.h>
@@ -50,6 +52,9 @@
 #define ENTRYEMAIL(e) TQString()
 #endif
 
+#define OPENDESKTOP_REDIRECT_URL "opendesktop.org/content/download.php?content="
+#define OPENDESKTOP_REDIRECT_TEXT "If the download does not start in 3 seconds:</span><span class=\"defaulttext\">&nbsp;<a href=\""
+
 namespace {
   static const int NEW_STUFF_MIN_WIDTH = 600;
   static const int NEW_STUFF_MIN_HEIGHT = 400;
@@ -79,7 +84,7 @@ public:
       return s;
     } else if(col == 4) {
       TQString s;
-      TQDate date = KGlobal::locale()->readDate(text(col));
+      TQDate date = TDEGlobal::locale()->readDate(text(col));
       s.sprintf("%08d", date.year() * 366 + date.dayOfYear());
       return s;
     }
@@ -99,7 +104,7 @@ Dialog::Dialog(NewStuff::DataType type_, TQWidget* parent_)
     , m_tempPreviewImage(0)
     , m_lastPreviewItem(0) {
 
-  m_lang = KGlobal::locale()->language();
+  m_lang = TDEGlobal::locale()->language();
 
   TQFrame* frame = plainPage();
   TQBoxLayout* boxLayout = new TQVBoxLayout(frame, 0, KDialog::spacingHint());
@@ -157,7 +162,7 @@ Dialog::Dialog(NewStuff::DataType type_, TQWidget* parent_)
 
   TQPixmap pix;
   if(m_type == EntryTemplate) {
-    pix = DesktopIcon(TQString::fromLatin1("looknfeel"), KIcon::SizeLarge);
+    pix = DesktopIcon(TQString::fromLatin1("preferences-desktop"), TDEIcon::SizeLarge);
     TQWhatsThis::add(m_install, i18n("Download and install the selected template."));
   } else {
     pix = UserIcon(TQString::fromLatin1("script"));
@@ -215,7 +220,7 @@ Dialog::Dialog(NewStuff::DataType type_, TQWidget* parent_)
   setMinimumHeight(TQMAX(minimumHeight(), NEW_STUFF_MIN_HEIGHT));
   resize(configDialogSize(TQString::fromLatin1("NewStuff Dialog Options")));
 
-  KConfigGroup dialogConfig(KGlobal::config(), "NewStuff Dialog Options");
+  TDEConfigGroup dialogConfig(TDEGlobal::config(), "NewStuff Dialog Options");
   TQValueList<int> splitList = dialogConfig.readIntListEntry("Splitter Sizes");
   if(!splitList.empty()) {
     m_split->setSizes(splitList);
@@ -223,30 +228,24 @@ Dialog::Dialog(NewStuff::DataType type_, TQWidget* parent_)
 
   setStatus(i18n("Downloading information..."));
 
-  ProviderLoader* loader = new Tellico::NewStuff::ProviderLoader(this);
-  connect(loader, TQT_SIGNAL(providersLoaded(TQPtrList<KNS::Provider>*)), TQT_SLOT(slotProviders(TQPtrList<KNS::Provider>*)));
-  connect(loader, TQT_SIGNAL(percent(KIO::Job*, unsigned long)), TQT_SLOT(slotShowPercent(KIO::Job*, unsigned long)));
-  connect(loader, TQT_SIGNAL(error()), TQT_SLOT(slotProviderError()));
+  KNS::ProviderLoader* loader = new KNS::ProviderLoader(this);
+  connect(loader, TQT_SIGNAL(providersLoaded(Provider::List*)), this, TQT_SLOT(slotProviders(Provider::List*)));
+  connect(loader, TQT_SIGNAL(percent(TDEIO::Job*, unsigned long)), this, TQT_SLOT(slotShowPercent(TDEIO::Job*, unsigned long)));
+  connect(loader, TQT_SIGNAL(error()), this, TQT_SLOT(slotProviderError()));
 
-  KConfigGroup config(KGlobal::config(), "KNewStuff");
+  TDEConfigGroup config(TDEGlobal::config(), "TDENewStuff");
   TQString prov = config.readEntry("ProvidersUrl");
   if(prov.isEmpty()) {
-    if(m_type == EntryTemplate) {
-      prov = TQString::fromLatin1("http://periapsis.org/tellico/newstuff/tellicotemplates-providers.php");
-      TQString alt = TQString::fromLatin1("http://download.kde.org/khotnewstuff/tellicotemplates-providers.xml");
-      loader->setAlternativeProvider(alt);
-    } else {
-      prov = TQString::fromLatin1("http://periapsis.org/tellico/newstuff/tellicoscripts-providers.php");
-    }
+    prov = TQString::fromLatin1("https://www.trinitydesktop.org/ocs/providers.xml");
   }
   if(m_type == EntryTemplate) {
-    m_typeName = TQString::fromLatin1("tellico/entry-template");
+    m_typeName = TQString::fromLatin1("tellico template");
   } else {
-    m_typeName = TQString::fromLatin1("tellico/data-source");
+    m_typeName = TQString::fromLatin1("tellico script");
   }
   loader->load(m_typeName, prov);
 
-  KAcceleratorManager::manage(this);
+  TDEAcceleratorManager::manage(this);
 }
 
 Dialog::~Dialog() {
@@ -254,7 +253,7 @@ Dialog::~Dialog() {
   m_cursorSaver = 0;
 
   saveDialogSize(TQString::fromLatin1("NewStuff Dialog Options"));
-  KConfigGroup config(KGlobal::config(), "NewStuff Dialog Options");
+  TDEConfigGroup config(TDEGlobal::config(), "NewStuff Dialog Options");
   config.writeEntry("Splitter Sizes", m_split->sizes());
 }
 
@@ -268,24 +267,24 @@ void Dialog::slotProviderError() {
   }
 }
 
-void Dialog::slotProviders(TQPtrList<KNS::Provider>* list_) {
+void Dialog::slotProviders(Provider::List* list_) {
   for(KNS::Provider* prov = list_->first(); prov; prov = list_->next()) {
-    KIO::TransferJob* job = KIO::get(prov->downloadUrl());
+    TDEIO::TransferJob* job = TDEIO::get(prov->downloadUrl());
     m_jobs[job] = prov;
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            TQT_SLOT(slotData(KIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(KIO::Job*)), TQT_SLOT(slotResult(KIO::Job*)));
-    connect(job, TQT_SIGNAL(percent(KIO::Job*, unsigned long)),
-            TQT_SLOT(slotShowPercent(KIO::Job*, unsigned long)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQT_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job*)), TQT_SLOT(slotResult(TDEIO::Job*)));
+    connect(job, TQT_SIGNAL(percent(TDEIO::Job*, unsigned long)),
+            TQT_SLOT(slotShowPercent(TDEIO::Job*, unsigned long)));
   }
 }
 
-void Dialog::slotData(KIO::Job* job_, const TQByteArray& data_) {
+void Dialog::slotData(TDEIO::Job* job_, const TQByteArray& data_) {
   TQDataStream stream(m_data[job_], IO_WriteOnly | IO_Append);
   stream.writeRawBytes(data_.data(), data_.size());
 }
 
-void Dialog::slotResult(KIO::Job* job_) {
+void Dialog::slotResult(TDEIO::Job* job_) {
 //  myDebug() << "NewStuff::Dialog::slotResult()" << endl;
   TQDomDocument dom;
   if(!dom.setContent(m_data[job_])) {
@@ -301,15 +300,26 @@ void Dialog::slotResult(KIO::Job* job_) {
     return;
   }
 
-  TQDomElement knewstuff = dom.documentElement();
+  TQDomElement tdenewstuff = dom.documentElement();
+  TQDomElement content;
 
-  for(TQDomNode pn = knewstuff.firstChild(); !pn.isNull(); pn = pn.nextSibling()) {
+  for(TQDomNode pn = tdenewstuff.firstChild(); !pn.isNull(); pn = pn.nextSibling())
+  {
+    TQDomElement stuff = pn.toElement();
+
+    if(stuff.tagName() == "data")
+    {
+      content = pn.toElement();
+    }
+  }
+
+  for(TQDomNode pn = content.firstChild(); !pn.isNull(); pn = pn.nextSibling()) {
     TQDomElement stuff = pn.toElement();
     if(stuff.isNull()) {
       continue;
     }
 
-    if(stuff.tagName() == Latin1Literal("stuff")) {
+    if(stuff.tagName() == Latin1Literal("content")) {
       KNS::Entry* entry = new KNS::Entry(stuff);
       if(!entry->type().isEmpty() && entry->type() != m_typeName) {
         myLog() << "NewStuff::Dialog::slotResult() - type mismatch, skipping " << ENTRYNAME(entry) << endl;
@@ -337,7 +347,7 @@ void Dialog::addEntry(KNS::Entry* entry_) {
   item->setText(1, entry_->version());
   item->setText(2, TQString::number(entry_->rating()));
   item->setText(3, TQString::number(entry_->downloads()));
-  item->setText(4, KGlobal::locale()->formatDate(entry_->releaseDate(), true /*short format */));
+  item->setText(4, TDEGlobal::locale()->formatDate(entry_->releaseDate(), true /*short format */));
   item->setStatus(NewStuff::Manager::installStatus(entry_));
   m_entryMap.insert(item, entry_);
 
@@ -364,14 +374,14 @@ void Dialog::slotSelected(TQListViewItem* item_) {
     m_tempPreviewImage->setAutoDelete(true);
     KURL dest;
     dest.setPath(m_tempPreviewImage->name());
-    KIO::FileCopyJob* job = KIO::file_copy(preview, dest, -1, true, false, false);
-    connect(job, TQT_SIGNAL(result(KIO::Job*)), TQT_SLOT(slotPreviewResult(KIO::Job*)));
-    connect(job, TQT_SIGNAL(percent(KIO::Job*, unsigned long)),
-            TQT_SLOT(slotShowPercent(KIO::Job*, unsigned long)));
+    TDEIO::FileCopyJob* job = TDEIO::file_copy(preview, dest, -1, true, false, false);
+    connect(job, TQT_SIGNAL(result(TDEIO::Job*)), TQT_SLOT(slotPreviewResult(TDEIO::Job*)));
+    connect(job, TQT_SIGNAL(percent(TDEIO::Job*, unsigned long)),
+            TQT_SLOT(slotShowPercent(TDEIO::Job*, unsigned long)));
     m_lastPreviewItem = item_;
   }
   TQPixmap pix = m_type == EntryTemplate
-              ? DesktopIcon(TQString::fromLatin1("looknfeel"), KIcon::SizeLarge)
+              ? DesktopIcon(TQString::fromLatin1("preferences-desktop"), TDEIcon::SizeLarge)
               : UserIcon(TQString::fromLatin1("script"));
   m_iconLabel->setPixmap(pix);
 
@@ -414,11 +424,78 @@ void Dialog::slotInstall() {
   m_progress->show();
   m_timer->start(100);
   connect(m_manager, TQT_SIGNAL(signalInstalled(KNS::Entry*)), TQT_SLOT(slotDoneInstall(KNS::Entry*)));
-  m_manager->install(m_type, entry);
+  mJobEntry = entry;
+
+  // OpenDesktop.org broke the basic functionality of TDEHNS by forcing
+  // downloads though an advertising display page.  This in turn forces
+  // the user to download and manually install the wallpaper, which
+  // is relatively complex and negates much of the benefit of TDEHNS.
+  // Therefore, if the download URL contains OPENDESKTOP_REDIRECT_URL
+  // then download the raw HTML page and extract the real download URL for use below.
+  // In the future we may want to figure out how to display unobtrusive ads
+  // during the download process, but OpenDesktop.org would need to add back
+  // in the direct download ability for this to even be considered.
+  if (entry->payload().url().contains(OPENDESKTOP_REDIRECT_URL)) {
+    TDEIO::TransferJob *job = TDEIO::get( KURL( entry->payload() ), false, false );
+    connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ),
+             TQT_SLOT( slotJobResult( TDEIO::Job * ) ) );
+    connect( job, TQT_SIGNAL( data( TDEIO::Job *, const TQByteArray & ) ),
+             TQT_SLOT( slotJobData( TDEIO::Job *, const TQByteArray & ) ) );
+  }
+  else {
+    slotInstallPhase2();
+  }
+}
+
+void Dialog::slotInstallPhase2() {
+  m_manager->install(m_type, mJobEntry);
   delete m_cursorSaver;
   m_cursorSaver = 0;
 }
 
+void Dialog::slotJobData( TDEIO::Job *, const TQByteArray &data )
+{
+  kdDebug() << "DownloadDialog::slotJobData()" << endl;
+
+  if ( data.size() == 0 ) return;
+
+  TQCString str( data, data.size() + 1 );
+
+  mJobData.append( TQString::fromUtf8( str ) );
+}
+
+void Dialog::slotJobResult( TDEIO::Job *job )
+{
+  if ( job->error() ) {
+    job->showErrorDialog( this );
+    slotInstallPhase2();
+    return;
+  }
+
+  // See previous note regarding OpenDesktop.org
+  if (mJobEntry->payload().url().contains(OPENDESKTOP_REDIRECT_URL)) {
+    int pos = mJobData.find("<a href=\"/CONTENT/content-files/");
+    if (pos >= 0) {
+      TQString realURL = mJobData.mid(pos);
+      realURL = realURL.mid(0, realURL.find("\">"));
+      realURL = realURL.mid(strlen("<a href=\""));
+      realURL = mJobEntry->payload().protocol() + "://opendesktop.org" + realURL;
+      mJobEntry->setPayload(realURL);
+    }
+    else if ((pos = mJobData.find(OPENDESKTOP_REDIRECT_TEXT)) > 0) {
+      pos = pos + strlen(OPENDESKTOP_REDIRECT_TEXT);
+      TQString realURL = mJobData.mid(pos);
+      realURL = realURL.mid(0, realURL.find("\">"));
+      mJobEntry->setPayload(realURL);
+    }
+  }
+
+  // Reset for next load
+  mJobData = TQString::null;
+
+  slotInstallPhase2();
+}
+
 void Dialog::slotDoneInstall(KNS::Entry* entry_) {
   TQMap<TQListViewItem*, KNS::Entry*>::Iterator it;
   for(it = m_entryMap.begin(); entry_ && it != m_entryMap.end(); ++it) {
@@ -444,7 +521,7 @@ void Dialog::setStatus(const TQString& text_) {
   m_statusBar->changeItem(TQChar(' ') + text_, PROGRESS_STATUS_ID);
 }
 
-void Dialog::slotShowPercent(KIO::Job*, unsigned long pct_) {
+void Dialog::slotShowPercent(TDEIO::Job*, unsigned long pct_) {
   if(pct_ >= 100) {
     m_progress->hide();
   } else {
@@ -453,8 +530,8 @@ void Dialog::slotShowPercent(KIO::Job*, unsigned long pct_) {
   }
 }
 
-void Dialog::slotPreviewResult(KIO::Job* job_) {
-  KIO::FileCopyJob* job = static_cast<KIO::FileCopyJob*>(job_);
+void Dialog::slotPreviewResult(TDEIO::Job* job_) {
+  TDEIO::FileCopyJob* job = static_cast<TDEIO::FileCopyJob*>(job_);
   if(job->error()) {
     return;
   }
