@@ -26,11 +26,12 @@
 #include "../tellico_debug.h"
 
 #include <kstandarddirs.h>
-#include <kconfig.h>
-#include <kglobal.h>
-#include <kio/netaccess.h>
-#include <kapplication.h>
-#include <klocale.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
+#include <tdeio/netaccess.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
+#include <kuser.h>
 
 #include <tqdom.h>
 #include <tqgroupbox.h>
@@ -192,6 +193,9 @@ bool HTMLExporter::loadXSLTFile() {
     m_handler = 0;
     return false;
   }
+  m_handler->addStringParam("date", TQDate::currentDate().toString(TQt::ISODate).latin1());
+  m_handler->addStringParam("time", TQTime::currentTime().toString(TQt::ISODate).latin1());
+  m_handler->addStringParam("user", KUser(KUser::UseRealUserID).loginName().latin1());
 
   if(m_exportEntryFiles) {
     // export entries to same place as all the other date files
@@ -209,7 +213,7 @@ bool HTMLExporter::loadXSLTFile() {
   // if parseDOM, that means we want the locations to be the actual location
   // otherwise, we assume it'll be relative
   if(m_parseDOM && m_dataDir.isEmpty()) {
-    m_dataDir = KGlobal::dirs()->findResourceDir("appdata", TQString::fromLatin1("pics/tellico.png"));
+    m_dataDir = TDEGlobal::dirs()->findResourceDir("appdata", TQString::fromLatin1("pics/tellico.png"));
   } else if(!m_parseDOM) {
     m_dataDir.truncate(0);
   }
@@ -279,7 +283,7 @@ void HTMLExporter::setFormattingOptions(Data::CollPtr coll) {
   if(file != i18n("Untitled")) {
     m_handler->addStringParam("filename", TQFile::encodeName(file));
   }
-  m_handler->addStringParam("cdate", KGlobal::locale()->formatDate(TQDate::currentDate()).utf8());
+  m_handler->addStringParam("cdate", TDEGlobal::locale()->formatDate(TQDate::currentDate()).utf8());
   m_handler->addParam("show-headers", m_printHeaders ? "true()" : "false()");
   m_handler->addParam("group-entries", m_printGrouped ? "true()" : "false()");
 
@@ -375,7 +379,7 @@ void HTMLExporter::setFormattingOptions(Data::CollPtr coll) {
   m_handler->addStringParam("color2",   TQString(Config::templateHighlightedBaseColor(type).name()).latin1());
 
   // add locale code to stylesheet (for sorting)
-  m_handler->addStringParam("lang",  KGlobal::locale()->languagesTwoAlpha().first().utf8());
+  m_handler->addStringParam("lang",  TDEGlobal::locale()->languagesTwoAlpha().first().utf8());
 }
 
 void HTMLExporter::writeImages(Data::CollPtr coll_) {
@@ -483,8 +487,8 @@ TQWidget* HTMLExporter::widget(TQWidget* parent_, const char* name_/*=0*/) {
   return m_widget;
 }
 
-void HTMLExporter::readOptions(KConfig* config_) {
-  KConfigGroup exportConfig(config_, TQString::fromLatin1("ExportOptions - %1").arg(formatString()));
+void HTMLExporter::readOptions(TDEConfig* config_) {
+  TDEConfigGroup exportConfig(config_, TQString::fromLatin1("ExportOptions - %1").arg(formatString()));
   m_printHeaders = exportConfig.readBoolEntry("Print Field Headers", m_printHeaders);
   m_printGrouped = exportConfig.readBoolEntry("Print Grouped", m_printGrouped);
   m_exportEntryFiles = exportConfig.readBoolEntry("Export Entry Files", m_exportEntryFiles);
@@ -495,8 +499,8 @@ void HTMLExporter::readOptions(KConfig* config_) {
                                       + m_entryXSLTFile + TQString::fromLatin1(".xsl"));
 }
 
-void HTMLExporter::saveOptions(KConfig* config_) {
-  KConfigGroup cfg(config_, TQString::fromLatin1("ExportOptions - %1").arg(formatString()));
+void HTMLExporter::saveOptions(TDEConfig* config_) {
+  TDEConfigGroup cfg(config_, TQString::fromLatin1("ExportOptions - %1").arg(formatString()));
   m_printHeaders = m_checkPrintHeaders->isChecked();
   cfg.writeEntry("Print Field Headers", m_printHeaders);
   m_printGrouped = m_checkPrintGrouped->isChecked();
@@ -535,7 +539,7 @@ TQString HTMLExporter::fileDirName() const {
 
 // how ugly is this?
 const xmlChar* HTMLExporter::handleLink(const xmlChar* link_) {
-  return reinterpret_cast<xmlChar*>(qstrdup(handleLink(TQString::fromUtf8(reinterpret_cast<const char*>(link_))).utf8()));
+  return reinterpret_cast<xmlChar*>(tqstrdup(handleLink(TQString::fromUtf8(reinterpret_cast<const char*>(link_))).utf8()));
 }
 
 TQString HTMLExporter::handleLink(const TQString& link_) {
@@ -562,7 +566,7 @@ TQString HTMLExporter::handleLink(const TQString& link_) {
   // the tmpDir() when exporting entry files from a collection, but those images
   // don't actually exist, and they get copied in writeImages() instead.
   // so we only need to keep track of the url if it exists
-  const bool exists = KIO::NetAccess::exists(u, false, 0);
+  const bool exists = TDEIO::NetAccess::exists(u, false, 0);
   if(exists) {
     m_files.append(u);
   }
@@ -585,7 +589,7 @@ TQString HTMLExporter::handleLink(const TQString& link_) {
 }
 
 const xmlChar* HTMLExporter::analyzeInternalCSS(const xmlChar* str_) {
-  return reinterpret_cast<xmlChar*>(qstrdup(analyzeInternalCSS(TQString::fromUtf8(reinterpret_cast<const char*>(str_))).utf8()));
+  return reinterpret_cast<xmlChar*>(tqstrdup(analyzeInternalCSS(TQString::fromUtf8(reinterpret_cast<const char*>(str_))).utf8()));
 }
 
 TQString HTMLExporter::analyzeInternalCSS(const TQString& str_) {
@@ -620,10 +624,10 @@ void HTMLExporter::createDir() {
     myDebug() << "HTMLExporter::createDir() - called on empty URL!" << endl;
     return;
   }
-  if(KIO::NetAccess::exists(dir, false, 0)) {
+  if(TDEIO::NetAccess::exists(dir, false, 0)) {
     m_checkCreateDir = false;
   } else {
-    m_checkCreateDir = !KIO::NetAccess::mkdir(dir, m_widget);
+    m_checkCreateDir = !TDEIO::NetAccess::mkdir(dir, m_widget);
   }
 }
 
@@ -647,12 +651,12 @@ bool HTMLExporter::copyFiles() {
       target = fileDir();
     }
     target.setFileName((*it).fileName());
-    bool success = KIO::NetAccess::file_copy(*it, target, -1, true /* overwrite */, false /* resume */, m_widget);
+    bool success = TDEIO::NetAccess::file_copy(*it, target, -1, true /* overwrite */, false /* resume */, m_widget);
     if(success) {
       m_copiedFiles.add((*it).url());
     } else {
       kdWarning() << "HTMLExporter::copyFiles() - can't copy " << target << endl;
-      kdWarning() << KIO::NetAccess::lastErrorString() << endl;
+      kdWarning() << TDEIO::NetAccess::lastErrorString() << endl;
     }
     if(j%stepSize == 0) {
       if(options() & ExportProgress) {
@@ -738,14 +742,14 @@ bool HTMLExporter::writeEntryFiles() {
     dataImages << TQString::fromLatin1("stars%1.png").arg(i);
   }
   KURL dataDir;
-  dataDir.setPath(KGlobal::dirs()->findResourceDir("appdata", TQString::fromLatin1("pics/tellico.png")) + "pics/");
+  dataDir.setPath(TDEGlobal::dirs()->findResourceDir("appdata", TQString::fromLatin1("pics/tellico.png")) + "pics/");
   KURL target = fileDir();
   target.addPath(TQString::fromLatin1("pics/"));
-  KIO::NetAccess::mkdir(target, m_widget);
+  TDEIO::NetAccess::mkdir(target, m_widget);
   for(TQStringList::ConstIterator it = dataImages.begin(); it != dataImages.end(); ++it) {
     dataDir.setFileName(*it);
     target.setFileName(*it);
-    KIO::NetAccess::copy(dataDir, target, m_widget);
+    TDEIO::NetAccess::copy(dataDir, target, m_widget);
   }
 
   return true;
